@@ -17,8 +17,8 @@
    Boston, MA 02110-1301, USA.
 */
 
-#ifndef CONTACTGRANTLEEPRINTADDRESSOBJECT_H
-#define CONTACTGRANTLEEPRINTADDRESSOBJECT_H
+#ifndef PRINT_CONTACTGRANTLEEADDRESSOBJECT_H
+#define PRINT_CONTACTGRANTLEEADDRESSOBJECT_H
 #include <QObject>
 #include <KContacts/Addressee>
 namespace KAddressBookGrantlee {
@@ -53,4 +53,4 @@ private:
     KContacts::Address mAddress;
 };
 }
-#endif // CONTACTGRANTLEEPRINTADDRESSOBJECT_H
+#endif // PRINT_CONTACTGRANTLEEADDRESSOBJECT_H
