@@ -17,8 +17,8 @@
    Boston, MA 02110-1301, USA.
 */
 
-#ifndef CONTACTGRANTLEEPRINTPHONEOBJECT_H
-#define CONTACTGRANTLEEPRINTPHONEOBJECT_H
+#ifndef PRINT_CONTACTGRANTLEEPHONEOBJECT_H
+#define PRINT_CONTACTGRANTLEEPHONEOBJECT_H
 #include <QObject>
 #include <KContacts/PhoneNumber>
 namespace KAddressBookGrantlee {
@@ -33,12 +33,12 @@ public:
     explicit ContactGrantleePhoneObject(const KContacts::PhoneNumber &phone, QObject *parent = nullptr);
     ~ContactGrantleePhoneObject();
 
-    QString type() const;
-    QString number() const;
-    bool preferred() const;
+    Q_REQUIRED_RESULT QString type() const;
+    Q_REQUIRED_RESULT QString number() const;
+    Q_REQUIRED_RESULT bool preferred() const;
 private:
     KContacts::PhoneNumber mPhoneNumber;
 };
 }
 
-#endif // CONTACTGRANTLEEPRINTPHONEOBJECT_H
+#endif // PRINT_CONTACTGRANTLEEPHONEOBJECT_H
